/**
 * Common namespace constants from the XMPP RFCs and XEPs.
 */
export type NS = {
    /**
     * - HTTP BIND namespace from XEP 124.
     */
    HTTPBIND: string;
    /**
     * - BOSH namespace from XEP 206.
     */
    BOSH: string;
    /**
     * - Main XMPP client namespace.
     */
    CLIENT: string;
    /**
     * - Legacy authentication namespace.
     */
    AUTH: string;
    /**
     * - Roster operations namespace.
     */
    ROSTER: string;
    /**
     * - Profile namespace.
     */
    PROFILE: string;
    /**
     * - Service discovery info namespace from XEP 30.
     */
    DISCO_INFO: string;
    /**
     * - Service discovery items namespace from XEP 30.
     */
    DISCO_ITEMS: string;
    /**
     * - Multi-User Chat namespace from XEP 45.
     */
    MUC: string;
    /**
     * - XMPP SASL namespace from RFC 3920.
     */
    SASL: string;
    /**
     * - XMPP Streams namespace from RFC 3920.
     */
    STREAM: string;
    /**
     * - XMPP Binding namespace from RFC 3920 and RFC 6120.
     */
    BIND: string;
    /**
     * - XMPP Session namespace from RFC 3920.
     */
    SESSION: string;
    /**
     * - XHTML-IM namespace from XEP 71.
     */
    XHTML_IM: string;
    /**
     * - XHTML body namespace from XEP 71.
     */
    XHTML: string;
    STANZAS: string;
    FRAMING: string;
};
export namespace NS {
    const HTTPBIND: string;
    const BOSH: string;
    const CLIENT: string;
    const SERVER: string;
    const AUTH: string;
    const ROSTER: string;
    const PROFILE: string;
    const DISCO_INFO: string;
    const DISCO_ITEMS: string;
    const MUC: string;
    const SASL: string;
    const STREAM: string;
    const FRAMING: string;
    const BIND: string;
    const SESSION: string;
    const VERSION: string;
    const STANZAS: string;
    const XHTML_IM: string;
    const XHTML: string;
}
export const PARSE_ERROR_NS: "http://www.w3.org/1999/xhtml";
export namespace XHTML {
    const tags: string[];
    namespace attributes {
        const a: string[];
        const blockquote: string[];
        const br: never[];
        const cite: string[];
        const em: never[];
        const img: string[];
        const li: string[];
        const ol: string[];
        const p: string[];
        const span: string[];
        const strong: never[];
        const ul: string[];
        const body: never[];
    }
    const css: string[];
}
/**
 * Connection status constants for use by the connection handler
 * callback.
 */
export type Status = {
    /**
     * - An error has occurred
     */
    ERROR: connstatus;
    /**
     * - The connection is currently being made
     */
    CONNECTING: connstatus;
    /**
     * - The connection attempt failed
     */
    CONNFAIL: connstatus;
    /**
     * - The connection is authenticating
     */
    AUTHENTICATING: connstatus;
    /**
     * - The authentication attempt failed
     */
    AUTHFAIL: connstatus;
    /**
     * - The connection has succeeded
     */
    CONNECTED: connstatus;
    /**
     * - The connection has been terminated
     */
    DISCONNECTED: connstatus;
    /**
     * - The connection is currently being terminated
     */
    DISCONNECTING: connstatus;
    /**
     * - The connection has been attached
     */
    ATTACHED: connstatus;
    /**
     * - The connection has been redirected
     */
    REDIRECT: connstatus;
    /**
     * - The connection has timed out
     */
    CONNTIMEOUT: connstatus;
    /**
     * - The JID resource needs to be bound for this session
     */
    BINDREQUIRED: connstatus;
    /**
     * - Failed to attach to a pre-existing session
     */
    ATTACHFAIL: connstatus;
    /**
     * - Not used by Strophe, but added for integrators
     */
    RECONNECTING: connstatus;
};
export namespace Status {
    const ERROR: number;
    const CONNECTING: number;
    const CONNFAIL: number;
    const AUTHENTICATING: number;
    const AUTHFAIL: number;
    const CONNECTED: number;
    const DISCONNECTED: number;
    const DISCONNECTING: number;
    const ATTACHED: number;
    const REDIRECT: number;
    const CONNTIMEOUT: number;
    const BINDREQUIRED: number;
    const ATTACHFAIL: number;
    const RECONNECTING: number;
}
export namespace ErrorCondition {
    const BAD_FORMAT: string;
    const CONFLICT: string;
    const MISSING_JID_NODE: string;
    const NO_AUTH_MECH: string;
    const UNKNOWN_REASON: string;
}
export namespace LOG_LEVELS {
    export const DEBUG: number;
    export const INFO: number;
    export const WARN: number;
    const ERROR_1: number;
    export { ERROR_1 as ERROR };
    export const FATAL: number;
}
export namespace ElementType {
    const NORMAL: number;
    const TEXT: number;
    const CDATA: number;
    const FRAGMENT: number;
}
export type connstatus = number;
/**
 * Logging level indicators.
 */
export type LogLevel = 0 | 1 | 2 | 3 | 4;
/**
 * Logging level indicators.
 */
export type LogLevelName = 'DEBUG' | 'INFO' | 'WARN' | 'ERROR' | 'FATAL';
/**
 * Logging level indicators.
 */
export type LogLevels = Record<LogLevelName, LogLevel>;
//# sourceMappingURL=constants.d.ts.map